<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Number of quoted characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use custom expiration timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Expiration timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show message content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>